package com.jiuqi.util;

import java.io.BufferedReader;
import java.io.FileReader;
import java.io.IOException;
import java.sql.Connection;
import java.sql.SQLException;
import java.sql.Statement;
import java.util.ArrayList;

/* loaded from: com_jiuqi_util.jar:com/jiuqi/util/DBConnect.class */
public abstract class DBConnect {
    public static final int SYNC_LEVEL_NO = 0;
    public static final int SYNC_LEVEL_ALL = 1;
    public static final int SYNC_LEVEL_THREAD = 2;
    private int conn_use = 0;
    private int translevel = 0;
    private boolean alreadyInTrans = false;
    protected Connection connection = null;
    public boolean disableTransaction = false;
    private int useSyncLevel = 1;
    private ThreadLocal connections = null;
    private Object threadMetux = null;

    protected abstract Connection createConnection() throws SQLException;

    protected void destroyConnection(Connection conn) throws SQLException {
        conn.close();
    }

    public void setSyncLevel(int value) {
        this.useSyncLevel = value;
        if (this.useSyncLevel == 2) {
            this.connections = new ThreadLocal();
            this.threadMetux = new Object();
        }
    }

    /* JADX WARN: Multi-variable type inference failed */
    /* JADX WARN: Type inference failed for: r0v11, types: [java.lang.Object] */
    /* JADX WARN: Type inference failed for: r0v12, types: [java.lang.Throwable] */
    /* JADX WARN: Type inference failed for: r0v18 */
    public Connection getConnection() throws SQLException {
        switch (this.useSyncLevel) {
            case 0:
                return null;
            case 1:
                return getConnection0();
            case 2:
                InnerConnection innerConn = (InnerConnection) this.connections.get();
                if (innerConn == null) {
                    ?? r0 = this.threadMetux;
                    synchronized (r0) {
                        innerConn = (InnerConnection) this.connections.get();
                        if (innerConn == null) {
                            innerConn = new InnerConnection();
                            this.connections.set(innerConn);
                        }
                        r0 = r0;
                    }
                }
                return innerConn.getConnection();
            default:
                return null;
        }
    }

    public void releaseConnection() {
        switch (this.useSyncLevel) {
            case 0:
            default:
                return;
            case 1:
                releaseConnection0();
                return;
            case 2:
                InnerConnection innerConn = (InnerConnection) this.connections.get();
                if (innerConn != null) {
                    innerConn.releaseConnection();
                    return;
                }
                return;
        }
    }

    private synchronized void releaseConnection0() {
        this.conn_use--;
        if (this.conn_use == 0) {
            try {
                try {
                    destroyConnection(this.connection);
                } catch (SQLException ex) {
                    ex.printStackTrace();
                }
            } finally {
                this.connection = null;
            }
        }
    }

    private synchronized Connection getConnection0() throws SQLException {
        if (this.connection == null) {
            try {
                this.connection = createConnection();
            } catch (SQLException ex) {
                throw ex;
            } catch (Exception ex2) {
                throw new SQLException(ex2.toString());
            }
        }
        this.conn_use++;
        return this.connection;
    }

    private Connection getConnection2() {
        switch (this.useSyncLevel) {
            case 0:
                return null;
            case 1:
                return this.connection;
            case 2:
                InnerConnection innerConn = (InnerConnection) this.connections.get();
                if (innerConn != null) {
                    return innerConn.connectionInner;
                }
                return null;
            default:
                return null;
        }
    }

    public synchronized void beginTrans() throws SQLException {
        if (this.disableTransaction) {
            return;
        }
        this.translevel++;
        if (this.translevel > 1) {
            return;
        }
        Connection conn = getConnection();
        this.alreadyInTrans = !conn.getAutoCommit();
        if (!this.alreadyInTrans) {
            conn.setAutoCommit(false);
        }
    }

    public synchronized void commitTrans() throws SQLException {
        if (this.disableTransaction) {
            return;
        }
        if (this.translevel <= 0) {
            throw new SQLException("不在事务内部，无法提交");
        }
        if (this.translevel != 1) {
            this.translevel--;
            return;
        }
        try {
            if (!this.alreadyInTrans) {
                getConnection2().commit();
            }
            try {
                this.translevel--;
                if (!this.alreadyInTrans) {
                    getConnection2().setAutoCommit(true);
                }
                releaseConnection();
            } catch (SQLException ex) {
                ex.printStackTrace();
            }
        } catch (SQLException ex2) {
            ex2.printStackTrace();
            throw ex2;
        }
    }

    public synchronized void cancelTrans() throws SQLException {
        if (this.disableTransaction) {
            return;
        }
        if (this.translevel <= 0) {
            throw new SQLException("不在事务内部，无法撤销");
        }
        if (this.translevel != 1) {
            this.translevel--;
            return;
        }
        try {
            if (!this.alreadyInTrans) {
                getConnection2().rollback();
            }
            try {
                if (!this.alreadyInTrans) {
                    getConnection2().setAutoCommit(true);
                }
            } catch (SQLException ex) {
                ex.printStackTrace();
            }
        } finally {
            this.translevel--;
            releaseConnection();
        }
    }

    public synchronized void setIsAutoCommit(boolean aIsAutoCommit) {
        this.alreadyInTrans = !aIsAutoCommit;
    }

    public static void runSql(Statement stmt, String sql) throws SQLException {
        boolean isEmpty = true;
        int i = 0;
        while (true) {
            if (i >= sql.length()) {
                break;
            }
            char ch = sql.charAt(i);
            if (!Character.isLetterOrDigit(ch)) {
                i++;
            } else {
                isEmpty = false;
                break;
            }
        }
        if (!isEmpty) {
            stmt.execute(sql);
        }
    }

    public static boolean endWith(String line, char ch) {
        if (line == null) {
            return false;
        }
        int index = line.length() - 1;
        while (index >= 0 && Character.isWhitespace(line.charAt(index))) {
            index--;
        }
        return index >= 0 && line.charAt(index) == ch;
    }

    public static void runScript(String scriptFile, ArrayList errors, Statement stmt) throws IOException, SQLException {
        FileReader fr = new FileReader(scriptFile);
        BufferedReader reader = new BufferedReader(fr);
        try {
            StringBuffer sql = new StringBuffer(1024);
            while (true) {
                String line = reader.readLine();
                if (line != null && !"GO".equalsIgnoreCase(line) && !endWith(line, ';')) {
                    sql.append(line);
                    sql.append('\n');
                } else if (line != null) {
                    if (endWith(line, ';')) {
                        int index = line.length() - 1;
                        while (index >= 0 && Character.isWhitespace(line.charAt(index))) {
                            index--;
                        }
                        sql.append(line.substring(0, index));
                    }
                    String sqlStmt = sql.toString();
                    sql.setLength(0);
                    if (errors == null) {
                        runSql(stmt, sqlStmt);
                    } else {
                        try {
                            runSql(stmt, sqlStmt);
                        } catch (Exception ex) {
                            errors.add(ex.getMessage());
                        }
                    }
                } else {
                    return;
                }
            }
        } finally {
            reader.close();
            fr.close();
        }
    }

    public void runScript(String scriptFile, ArrayList errors) throws IOException, SQLException {
        Connection conn = getConnection();
        try {
            Statement stmt = conn.createStatement(1003, 1007);
            runScript(scriptFile, errors, stmt);
        } finally {
            releaseConnection();
        }
    }

    public static boolean isUniqueViolationException(SQLException ex) {
        String msg = ex.getMessage();
        if (msg == null) {
            return false;
        }
        String msg2 = msg.toLowerCase();
        if (msg2.indexOf("unique") >= 0 || msg2.indexOf("primary key") >= 0 || msg2.indexOf("唯一") >= 0 || msg2.indexOf("主键") >= 0) {
            return msg2.indexOf("violate") >= 0 || msg2.indexOf("违反") >= 0;
        }
        return false;
    }

    /* JADX INFO: Access modifiers changed from: package-private */
    /* loaded from: com_jiuqi_util.jar:com/jiuqi/util/DBConnect$InnerConnection.class */
    public class InnerConnection {
        int connUser = 0;
        Connection connectionInner = null;

        InnerConnection() {
        }

        public synchronized Connection getConnection() throws SQLException {
            if (this.connectionInner == null) {
                try {
                    this.connectionInner = DBConnect.this.createConnection();
                } catch (SQLException ex) {
                    throw ex;
                } catch (Exception ex2) {
                    throw new SQLException(ex2.toString());
                }
            }
            this.connUser++;
            return this.connectionInner;
        }

        public synchronized void releaseConnection() {
            this.connUser--;
            if (this.connUser == 0) {
                try {
                    try {
                        DBConnect.this.destroyConnection(this.connectionInner);
                    } catch (SQLException ex) {
                        ex.printStackTrace();
                    }
                } finally {
                    this.connectionInner = null;
                }
            }
        }
    }
}
